=======
History
=======

1.2.0 (2020-06-21)
------------------

Added
******
* Updated API to make imports easier (for example: 'from pairwisedist import jackknife_distance' instead of 'from pairwisedist.pairwisedist import jackknife_distance').
* Added pearson_distance() and spearman_distance().

1.1.0 (2020-06-21)
------------------

Added
******
* Added jackknife_distance().


1.0.0 (2020-06-18)
------------------

* First release on PyPI.

Added
******
* Added ys1_distance() and yr1_distance().
